import { ApolloLink, FetchResult } from 'apollo-link-core';
import { Cache, DataProxy, DataProxyReadQueryOptions, DataProxyReadFragmentOptions, DataProxyWriteQueryOptions, DataProxyWriteFragmentOptions, DiffResult } from 'apollo-cache-core';
import { QueryManager } from './core/QueryManager';
import { ApolloQueryResult } from './core/types';
import { ObservableQuery } from './core/ObservableQuery';
import { Observable } from './util/Observable';
import { WatchQueryOptions, SubscriptionOptions, MutationOptions } from './core/watchQueryOptions';
import { DataStore } from './data/store';
export default class ApolloClient implements DataProxy {
    link: ApolloLink;
    store: DataStore;
    queryManager: QueryManager;
    disableNetworkFetches: boolean;
    version: string;
    queryDeduplication: boolean;
    private devToolsHookCb;
    private proxy;
    private ssrMode;
    constructor(options: {
        link: ApolloLink;
        cache: Cache;
        ssrMode?: boolean;
        ssrForceFetchDelay?: number;
        connectToDevTools?: boolean;
        queryDeduplication?: boolean;
    });
    watchQuery<T>(options: WatchQueryOptions): ObservableQuery<T>;
    query<T>(options: WatchQueryOptions): Promise<ApolloQueryResult<T>>;
    mutate<T>(options: MutationOptions<T>): Promise<FetchResult<T>>;
    subscribe(options: SubscriptionOptions): Observable<any>;
    readQuery<T>(options: DataProxyReadQueryOptions): DiffResult<T>;
    readFragment<T>(options: DataProxyReadFragmentOptions): DiffResult<T> | null;
    writeQuery(options: DataProxyWriteQueryOptions): void;
    writeFragment(options: DataProxyWriteFragmentOptions): void;
    __actionHookForDevTools(cb: Function): void;
    initQueryManager(): void;
    resetStore(): Promise<ApolloQueryResult<any>[]> | null;
    private initProxy();
}
